package org.bouncycastle.jce.cert;

import java.security.cert.CRL;

/**
 * A selector that defines a set of criteria for selecting  CRL</code>s.
 * Classes that implement this interface are often used to specify
 * which  CRL</code>s should be retrieved from a  CertStore</code>.<br />
 * <br />
 * <b>Concurrent Access</b><br />
 * <br />
 * Unless otherwise specified, the methods defined in this interface are not
 * thread-safe. Multiple threads that need to access a single
 * object concurrently should synchronize amongst themselves and
 * provide the necessary locking. Multiple threads each manipulating
 * separate objects need not synchronize.
 *
 * @see CRL
 * @see CertStore
 * @see CertStore#getCRLs
 **/
public interface CRLSelector extends Cloneable
{
    /**
     * Decides whether a  CRL</code> should be selected.
     *
     * @param crl the  CRL</code> to be checked
     *
     * @return  true</code> if the  CRL</code> should be selected, 
     *  false</code> otherwise
     */
    public boolean match(CRL crl);

    /**
     * Makes a copy of this  CRLSelector</code>. Changes to the 
     * copy will not affect the original and vice versa.
     *
     * @return a copy of this  CRLSelector</code>
     */
    public Object clone();
}
